@@ -43,14 +43,15 @@ class util(object):
 		if os.actions : helpers.bulk(client=self.es,actions=os.actions, raise_on_error=False)
 		print(">>load finished:" , infile, idxname, len(os.actions) )
 
-	def spacysnt(self, infile, index:str=None, batch=200000,tok:bool=False, np:bool=False): 
+	def spacysnt(self, infile, index:str=None, batch=200000,tok:bool=False, np:bool=False, topk:int=None): 
 		''' python3 -m api.sntjson-es gzjc.jsonlg.3.4.1.gz'''
 		os.index = index if index is not None else infile.split('.')[0]
-		print(f">>load started: host={self.host}, index={os.index} " , infile, os.index, flush=True )
+		print(f">>[es-index spacysnt] load started: host={self.host}, index={os.index} " , infile, os.index, flush=True )
 		if not self.es.indices.exists(index=os.index): self.es.indices.create(index=os.index, body=so.config) 
 				
 		for sid, line in enumerate(fileinput.input(infile,openhook=fileinput.hook_compressed)): 
 			try:
+				if topk is not None and sid > topk : break  # added 2023.3.17
 				doc = Doc(spacy.nlp.vocab).from_json(json.loads(line.strip())) 
 				index_snt(sid, doc, tok, np) 
 				self._submit(batch) 
@@ -59,12 +60,12 @@ class util(object):
 				exc_type, exc_value, exc_obj = sys.exc_info() 	
 				traceback.print_tb(exc_obj)
 		if os.actions : helpers.bulk(client=self.es,actions=os.actions, raise_on_error=False)
-		print(">>load finished:" , infile, os.index )
+		print(">>[es-index spacysnt] load finished:" , infile, sid, os.index )
 
 	def spacydoc(self, infile, index:str=None, batch=200000,tok:bool=False, np:bool=False): 
 		''' spider-aa.docjsonlg.3.4.1.gz '''
 		os.index = index if index is not None else infile.split('.')[0].lower()
-		print(f">>load started: host={self.host}, index={os.index} " , infile, os.index, flush=True )
+		print(f">>[es-index spacydoc] load started: host={self.host}, index={os.index} " , infile, os.index, flush=True )
 		if not self.es.indices.exists(index=os.index): self.es.indices.create(index=os.index, body=so.config) 
 				
 		for did, line in enumerate(fileinput.input(infile,openhook=fileinput.hook_compressed)): 
@@ -80,7 +81,7 @@ class util(object):
 				exc_type, exc_value, exc_obj = sys.exc_info() 	
 				traceback.print_tb(exc_obj)
 		if os.actions : helpers.bulk(client=self.es,actions=os.actions, raise_on_error=False)
-		print(">>spacydoc finished:" , infile, os.index )
+		print(">>[es-index spacydoc] finished:" , infile, os.index )
 
 	def es_submit(self, infile, index:str=None, batch=200000, recreate:bool=True, host='172.17.0.1',port=9200): 
 		''' python3 -m api.sntjson-es gzjc.jsonlg.3.4.1.gz'''
