@@ -1,6 +1,6 @@
 # 2022.7.21 , sit(text),  select * from gzjc_snt where sid = '3,xx2,3'/substring_index('1,2,3',',',1)
 # 2022.7.6 cp from silite.py, since clickhouse DONOT support  sql with 'match' 
-import json, traceback,sys, time, fire,os,traceback
+import json, traceback,sys, time, fire,os,traceback,fileinput
 from collections import	Counter, defaultdict
 import en 
 from en.spacybs import Spacybs
@@ -9,12 +9,13 @@ add = lambda *names: [fire.si.update({name: 1}) for name in names if  not '\t' i
 reg = lambda name, sid: fire.st[name].append(sid) if len(fire.st[name]) <= 100 else None
 
 def walk(sid, doc): 
+	from dic.wordlist import wordlist 
 	add(f"#SNT")  #, f"{t.tag_}:{t.lemma_.lower()}" where s like '%:VERB:VBG' => where s like 'VBG:%'
 	[add( f"{t.lemma_}:POS:{t.pos_}", f"{t.lemma_}:LEX:{t.text.lower()}", f"LEM:{t.lemma_.lower()}", f"LEX:{t.text.lower()}", f"{t.pos_}:{t.lemma_.lower()}"
-		,f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}:{t.text.lower()}",f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}",f"*:{t.pos_}:{t.tag_}", f"{t.lemma_.lower()}:{t.pos_}") for t in doc if not t.pos_ in ('PROPN','X', 'PUNCT') and t.is_alpha ]
+		,f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}:{t.text.lower()}",f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}",f"*:{t.pos_}:{t.tag_}", f"{t.lemma_.lower()}:{t.pos_}") for t in doc if not t.pos_ in ('PROPN','X', 'PUNCT') and t.is_alpha  and t.lemma_.lower() in wordlist]
 	for t in doc:
-		add( "#LEX", f"#{t.pos_}", f"#{t.tag_}",f"#{t.dep_}",) # book:VERB:VBG
-		if t.pos_ not in ("PROPN","PUNCT","SPACE") and t.is_alpha and t.head.is_alpha: #*:VERB:~punct:VERB:wink
+		add( "#LEX", f"#{t.pos_}", f"*:{t.pos_}", f"#{t.tag_}",f"#{t.dep_}",) # book:VERB:VBG
+		if t.pos_ not in ("PROPN","PUNCT","SPACE") and t.is_alpha and t.head.is_alpha and t.lemma_.lower() in wordlist and t.head.lemma_.lower() in wordlist: #*:VERB:~punct:VERB:wink
 			reg(f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}:{t.text.lower()}", sid) 
 			add(f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}:{t.lemma_}", f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}",f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}", f"*:{t.head.pos_}:{t.dep_}")
 			reg(f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}:{t.lemma_}", sid)
@@ -90,6 +91,60 @@ END''')
 		my_conn.commit()
 	print ("finished submitting:", dbfile, flush=True) 
 
+def tsv(jsonfile, cutoff=0, model:str="lg"):  
+	''' gzjc.json341.gz => gzjc.tsv.si, gzjc.tsv.snt , added 2022.7.30 '''
+	import spacy 
+	nlp =spacy.load(f'en_core_web_{model}')
+	print ("started index:", jsonfile, model, flush=True)
+	name = jsonfile.lower().split('.')[0]
+	fire.si = Counter()
+	fire.st = defaultdict(list)
+	with open (f"{name}.tsv.snt", "w", encoding='UTF-8') as fw:
+		for rowid, line in enumerate(fileinput.input(jsonfile,openhook=fileinput.hook_compressed)): 
+			try: 
+				doc_json =json.loads(line) 
+				doc = Doc(nlp.vocab).from_json(doc_json)
+				terms = " ".join([ f"{t.lemma_}_{t.pos_}" for t in doc] + [ f"{t.lemma_}_{t.tag_}" for t in doc] + [ f"{t.head.lemma_}_{t.head.pos_}_{t.dep_}_{t.pos_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp','prep')]) 
+				fw.write(f"{rowid}\t{doc_json['text']}\t{terms}\n")
+				walk(rowid, doc)
+			except Exception as e:
+				print ("ex:", e, rowid, line)
+	with open (f"{name}.tsv.sit", "w", encoding='UTF-8') as fw:
+		[ fw.write(f"{k}\t{v}\t{','.join([str(sid) for sid in fire.st[k] ])}\n") for k,v in fire.si.items() if v > cutoff ] 
+	os.system(f"gzip -f -9 {name}.tsv.sit")
+	os.system(f"gzip -f -9 {name}.tsv.snt")
+	print ("finished submitting:", jsonfile, flush=True) 
+
+def doctsv(jsonfile, cutoff=0, model:str="lg", didkey:str='did'):   
+	''' gzjc.json341.gz => gzjc.tsv.si, gzjc.tsv.snt , added 2022.8.4 '''
+	import spacy 
+	nlp =spacy.load(f'en_core_web_{model}')
+	print ("started index:", jsonfile, model, flush=True)
+	name = jsonfile.lower().split('.')[0]
+	fire.si = Counter()
+	fire.st = defaultdict(list)
+	with open (f"{name}.sntjson", "w", encoding='UTF-8') as fw:
+		for line in fileinput.input(jsonfile,openhook=fileinput.hook_compressed): 
+			try: 
+				doc_json =json.loads(line) 
+				did = int(doc_json['info']['did'])
+				del doc_json['info']
+				tdoc = Doc(nlp.vocab).from_json(doc_json)
+				for i, snt in enumerate(tdoc.sents): 
+					doc = snt.as_doc()
+					terms = " ".join([ f"{t.lemma_}_{t.pos_}" for t in doc] + [ f"{t.lemma_}_{t.tag_}" for t in doc] + [ f"{t.head.lemma_}_{t.head.pos_}_{t.dep_}_{t.pos_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp','prep')]) 
+					rowid = did * 10000 + i 
+					arr = {"sid":rowid, "snt":snt.text.strip(), "kps": terms}
+					fw.write(json.dumps(arr) + "\n")
+					walk(rowid, doc)
+			except Exception as e:
+				print ("ex:", e, line)
+	with open (f"{name}.tsv.sit", "w", encoding='UTF-8') as fw:
+		[ fw.write(f"{k}\t{v}\t{','.join([str(sid) for sid in fire.st[k] ])}\n") for k,v in fire.si.items() if v > cutoff ] 
+	os.system(f"gzip -f -9 {name}.tsv.sit")
+	os.system(f"gzip -f -9 {name}.sntjson")
+	print ("finished submitting:", jsonfile, flush=True) 
+
 def kpyes(dbfile, host='127.0.0.1', port=3309):  
 	''' dic.spacybs -> kpyes , 2022.7.13 '''
 	import pymysql
@@ -139,8 +194,33 @@ def load(name, port=3307):
 	os.system(f"gzip -d {name}.sql.gz") if os.path.exists(f"{name}.sql.gz") else None 
 	os.system(f"mysql -uroot -pcikuutest! -h 127.0.0.1 --port {port} kpsi  < {name}.sql")
 
+def loadtsv(infile, host='127.0.0.1', port=3307, cutoff=0): 
+	''' clec.jsonlg.3.4.1.gz -> mysql:kpsi/clec,clec_snt , 2022.7.31 '''
+	import pymysql
+	print ("started loadtsv:", infile, flush=True)
+	name = infile.lower().split('.')[0]
+	my_conn = pymysql.connect(host=host,port=port,user='root',password='cikuutest!',db='kpsi')
+	with my_conn.cursor() as cursor: 
+		arr  = [line.decode().split('\t') for line in fileinput.input(infile,openhook=fileinput.hook_compressed)]
+		if infile.endswith(".tsv.sit.gz"):
+			cursor.execute(f"drop TABLE if exists {name}")
+			cursor.execute(f"CREATE TABLE if not exists {name}(s varchar(128) COLLATE latin1_bin not null primary key, i int not null default 0, t text) engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin") # not null default ''
+			cursor.executemany(f"insert ignore into {name}(s, i, t) values(%s, %s, %s)", arr) 
+		elif infile.endswith(".tsv.snt.gz"):
+			cursor.execute(f"drop TABLE if exists {name}_snt")
+			cursor.execute(f"CREATE TABLE if not exists {name}_snt(sid int primary key, snt text not null, kps text not null, fulltext key `snt`(`snt`), fulltext key `kps`(`kps`) ) engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
+			cursor.executemany(f"insert ignore into {name}_snt(sid, snt, kps) values(%s, %s, %s)", arr) 
+		#for line in fileinput.input(infile,openhook=fileinput.hook_compressed): 
+		#	arr = line.decode().split('\t')
+		#	if infile.endswith(".tsv.sit.gz"):
+		#		cursor.execute(f"insert ignore into {name}(s, i, t) values(%s, %s, %s)", (arr[0], arr[1], arr[2]) )
+		#	elif infile.endswith(".tsv.snt.gz"):
+		#		cursor.execute(f"insert ignore into {name}_snt(sid, snt, kps) values(%s, %s, %s)", (arr[0], arr[1], arr[2]))
+	my_conn.commit()
+	print ("finished submitting:", infile, flush=True) 
+
 if __name__	== '__main__':
-	fire.Fire({"mysql":mysql, "batch":batch, 'trp':trp , 'kpyes':kpyes, "dump":dump, "load":load})
+	fire.Fire({"mysql":mysql, "batch":batch, 'trp':trp , 'kpyes':kpyes, "dump":dump, "load":load, "tsv":tsv, "loadtsv":loadtsv, 'doctsv':doctsv})
 
 '''
 mysqldump -uroot -pcikuutest! --port 3307 --host=172.18.0.1 kpsi word_attr --result-file=word_attr.sql
