@@ -27,6 +27,7 @@ config = {
 					#"(^([^_]+)_[a-z]+[,\\.$]?)",  
 					"(^[^_]+)",   # first lex
 					"(_[a-z]+_[VERB|NOUN|ADJ|ADV]+)", # lex_tag_lem_pos , _contact_VERB (VERB|NOUN|ADJ|ADV)
+					"(_[a-z]+_VERB_[VBD|VBP|VBG|VBZ|VB]+_)",  # except VBN, 2023.3.20
 					#"(_[a-zA-Z\\-\\.\\'\\$0-9]+)$",  # remove _NP5,  _NP5 => _NP 
 					"(_[a-zA-Z,\\-\\.\\'\\$\\*]+)",  # _^ _ADJ _, _NOUN _VERB , _open/VERB 
 					#"(_[^\\w]+)_",
@@ -39,6 +40,12 @@ config = {
 					  "replacement": "$2/$3",  # _open_VERB => open/VERB
 					  "all": False
 					},
+				"postag_filterV": {
+					  "type": "pattern_replace",
+					  "pattern": "(^_([a-z]+)(_VERB_[VBD|VBP|VBG|VBZ|VB]+)_)",
+					  "replacement": "$2/V",  # _open_VERB_VBD => open/V
+					  "all": False
+					},
 				"postag_filter2": {
 				  "type": "word_delimiter",
 				  "type_table": [
@@ -71,7 +78,7 @@ config = {
 				}
 			  },
 			  "analyzer": {
-				"postag_ana": {"filter": ["postag_filter", "postag_filter1", "postag_filter2", "unique_filter"], "type": "custom", "tokenizer": "whitespace" }, #"lowercase",
+				"postag_ana": {"filter": ["postag_filter", "postag_filterV", "postag_filter1",  "postag_filter2", "unique_filter"], "type": "custom", "tokenizer": "whitespace" }, #"lowercase",
 				"path_ana": {"type": "custom", "tokenizer": "path-tokenizer"},
 				"path_ana3": {"type": "custom", "tokenizer": "path-tokenizer3"},
 				"feedback_ana": {"type": "custom", "tokenizer": "feedback-tokenizer"},
@@ -476,6 +483,9 @@ def init(idxname):
 	print(">>finished " + idxname )
 
 def testana(index:str='test'):
+	requests.eshost	= os.getenv("eshost", "sntvec.wrask.com:9200") 
+	requests.es		= Elasticsearch([ f"http://{requests.eshost}" ])  
+	init( index ) 
 	arr = requests.post(f"http://sntvec.wrask.com:9200/{index}/_analyze", json={
   "analyzer": "postag_ana",
   "text": "booked_book_VERB_VBD_NP5"
@@ -484,7 +494,8 @@ def testana(index:str='test'):
 		print (t) 
 
 if __name__ == "__main__": 
-	fire.Fire({"init":init,"test":testana}) 
+	import platform
+	testana() if platform.system() in ('Windows') else fire.Fire({"init":init,"test":testana}) 
 	
 '''
 {'tokens': [{'token': 'booked', 'start_offset': 0, 'end_offset': 22, 'type': 'word', 'position': 0}, 
