@@ -296,7 +296,7 @@ def snt_kps(text:str="She has ready. It are ok. The justice delayed is justice d
 	id_source = {} # used for es PUT 
 	for sid, snt in enumerate(tdoc.sents): 
 		doc = snt.as_doc() 
-		postag = "_^ " + ' '.join([ f"_{t.pos_}_{t.tag_}" if t.pos_ in ('PROPN','NUM','X','SPACE','PUNCT') else f"{t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}" for t in doc])
+		postag = "_^ " + ' '.join([ f"{t.text}_{t.pos_}_{t.tag_}" if t.pos_ in ('PROPN','NUM','X','SPACE','PUNCT') else f"{t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}" for t in doc])
 
 		_kps = []
 		[ _kps.append(f"{t.pos_}:{t.lemma_}") for t in doc]  # VERB:book
